summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBuddybenj <buddybenj@gmail.com>2014-10-31 21:58:14 -0500
committerBuddybenj <buddybenj@gmail.com>2014-11-01 17:42:13 -0500
commita4e48ab1a135155a42e70dfdad26c4e2c8ccf863 (patch)
treef7bbbb5f2f5b8a2a990059ffddd1383541f61734
parent9c7d4b6408b496e15757a1bfceed5b24a075e3b5 (diff)
Nunchuck -> Nunchuk
Change another can not to cannot Nunchuck -> Nunchuk Nunchuck -> Nunchuk Nunchuck -> Nunchuk Nunchuck -> Nunchuk Nunchuck -> Nunchuk Nunchuck -> Nunchuk Nunchuck -> Nunchuk
-rw-r--r--Data/Sys/GameSettings/GWRE01.ini2
-rw-r--r--Data/Sys/GameSettings/REDE41.ini2
-rw-r--r--Data/Sys/GameSettings/REDJ41.ini2
-rw-r--r--Data/Sys/GameSettings/REDP41.ini2
-rw-r--r--Source/Core/Core/HW/WiimoteEmu/Attachment/Nunchuk.cpp10
-rw-r--r--Source/Core/Core/HW/WiimoteEmu/EmuSubroutines.cpp14
-rw-r--r--Source/Core/Core/HW/WiimoteEmu/WiimoteEmu.cpp2
7 files changed, 17 insertions, 17 deletions
diff --git a/Data/Sys/GameSettings/GWRE01.ini b/Data/Sys/GameSettings/GWRE01.ini
index 2b62d176db..1e074a4c0e 100644
--- a/Data/Sys/GameSettings/GWRE01.ini
+++ b/Data/Sys/GameSettings/GWRE01.ini
@@ -20,7 +20,7 @@ $Always 0 missed Buoys
046199F4 00000000
$Always turbo
04620FDC 0000004B
-$Never 'out of bounds' - can not finish race
+$Never 'out of bounds' - cannot finish race
04619BD4 00000000
$Stunt mode: Massive score
0461B2B8 05F5E0FF
diff --git a/Data/Sys/GameSettings/REDE41.ini b/Data/Sys/GameSettings/REDE41.ini
index 8f5399fc2d..882a940a5a 100644
--- a/Data/Sys/GameSettings/REDE41.ini
+++ b/Data/Sys/GameSettings/REDE41.ini
@@ -6,7 +6,7 @@
[EmuState]
# The Emulation State. 1 is worst, 5 is best, 0 is not set.
EmulationStateId = 3
-EmulationIssues = Nunchuck doesn't work (both real and emulated).
+EmulationIssues = Nunchuk doesn't work (both real and emulated).
[OnLoad]
# Add memory patches to be loaded once on boot here.
diff --git a/Data/Sys/GameSettings/REDJ41.ini b/Data/Sys/GameSettings/REDJ41.ini
index 9916386167..9552ed8b5b 100644
--- a/Data/Sys/GameSettings/REDJ41.ini
+++ b/Data/Sys/GameSettings/REDJ41.ini
@@ -6,7 +6,7 @@
[EmuState]
# The Emulation State. 1 is worst, 5 is best, 0 is not set.
EmulationStateId = 3
-EmulationIssues = Nunchuck doesn't work (both real and emulated).
+EmulationIssues = Nunchuk doesn't work (both real and emulated).
[OnLoad]
# Add memory patches to be loaded once on boot here.
diff --git a/Data/Sys/GameSettings/REDP41.ini b/Data/Sys/GameSettings/REDP41.ini
index 65d5271d87..2ee6119f43 100644
--- a/Data/Sys/GameSettings/REDP41.ini
+++ b/Data/Sys/GameSettings/REDP41.ini
@@ -6,7 +6,7 @@
[EmuState]
# The Emulation State. 1 is worst, 5 is best, 0 is not set.
EmulationStateId = 3
-EmulationIssues = Nunchuck doesn't work (both real and emulated).
+EmulationIssues = Nunchuk doesn't work (both real and emulated).
[OnLoad]
# Add memory patches to be loaded once on boot here.
diff --git a/Source/Core/Core/HW/WiimoteEmu/EmuSubroutines.cpp b/Source/Core/Core/HW/WiimoteEmu/EmuSubroutines.cpp
index 8420f73195..717baadcf8 100644
--- a/Source/Core/Core/HW/WiimoteEmu/EmuSubroutines.cpp
+++ b/Source/Core/Core/HW/WiimoteEmu/EmuSubroutines.cpp
@@ -387,7 +387,7 @@ void Spy(Wiimote* wm_, const void* data_, size_t size_)
//INFO_LOG(CONSOLE, "Extension ID: %s", ArrayToString(rdr->data, rdr->size+1).c_str());
}
- // Nunchuck calibration
+ // Nunchuk calibration
if (data[4] == 0xf0 && data[5] == 0x00 && (data[6] == 0x20 || data[6] == 0x30))
{
// log
@@ -397,9 +397,9 @@ void Spy(Wiimote* wm_, const void* data_, size_t size_)
//if(((u8*)&wm->m_reg_ext)[0xf0] == 0xaa) {
// WiimoteDecrypt(&wm->m_ext_key, &data[0x07], 0x00, (data[4] >> 0x04) + 1);
- //if (wm->m_extension->name == "NUNCHUCK")
+ //if (wm->m_extension->name == "NUNCHUK")
//{
- // INFO_LOG(CONSOLE, "\nGame got the Nunchuck calibration:\n");
+ // INFO_LOG(CONSOLE, "\nGame got the Nunchuk calibration:\n");
// INFO_LOG(CONSOLE, "Cal_zero.x: %i\n", data[7 + 0]);
// INFO_LOG(CONSOLE, "Cal_zero.y: %i\n", data[7 + 1]);
// INFO_LOG(CONSOLE, "Cal_zero.z: %i\n", data[7 + 2]);
@@ -441,18 +441,18 @@ void Spy(Wiimote* wm_, const void* data_, size_t size_)
//memcpy((u8*)&wm->m_reg_ext.calibration, &data[7], 0x10);
//memcpy((u8*)&wm->m_reg_ext.unknown3, &data[7], 0x10);
}
- // Save the default values that should work with Wireless Nunchucks
+ // Save the default values that should work with Wireless Nunchuks
else
{
//WiimoteEmu::SetDefaultExtensionRegistry();
}
//WiimoteEmu::UpdateEeprom();
}
- // third party Nunchuck
+ // third party Nunchuk
else if (data[7] == 0xff)
{
- //memcpy(wm->m_reg_ext + 0x20, WiimoteEmu::wireless_nunchuck_calibration, sizeof(WiimoteEmu::wireless_nunchuck_calibration));
- //memcpy(wm->m_reg_ext + 0x30, WiimoteEmu::wireless_nunchuck_calibration, sizeof(WiimoteEmu::wireless_nunchuck_calibration));
+ //memcpy(wm->m_reg_ext + 0x20, WiimoteEmu::wireless_nunchuk_calibration, sizeof(WiimoteEmu::wireless_nunchuk_calibration));
+ //memcpy(wm->m_reg_ext + 0x30, WiimoteEmu::wireless_nunchuk_calibration, sizeof(WiimoteEmu::wireless_nunchuk_calibration));
}
// print encrypted data
diff --git a/Source/Core/Core/HW/WiimoteEmu/WiimoteEmu.cpp b/Source/Core/Core/HW/WiimoteEmu/WiimoteEmu.cpp
index e6c3e00a3b..19f3b63606 100644
--- a/Source/Core/Core/HW/WiimoteEmu/WiimoteEmu.cpp
+++ b/Source/Core/Core/HW/WiimoteEmu/WiimoteEmu.cpp
@@ -569,7 +569,7 @@ void Wiimote::GetExtData(u8* const data)
{
switch (m_reg_motion_plus.ext_identifier[0x4])
{
- // nunchuck pass-through mode
+ // nunchuk pass-through mode
// Bit 7 of byte 5 is moved to bit 6 of byte 5, overwriting it
// Bit 0 of byte 4 is moved to bit 7 of byte 5
// Bit 3 of byte 5 is moved to bit 4 of byte 5, overwriting it
diff --git a/Source/Core/Core/HW/WiimoteEmu/Attachment/Nunchuk.cpp b/Source/Core/Core/HW/WiimoteEmu/Attachment/Nunchuk.cpp
index 578c3b9126..78d8d74850 100644
--- a/Source/Core/Core/HW/WiimoteEmu/Attachment/Nunchuk.cpp
+++ b/Source/Core/Core/HW/WiimoteEmu/Attachment/Nunchuk.cpp
@@ -7,11 +7,11 @@
namespace WiimoteEmu
{
-static const u8 nunchuck_id[] = { 0x00, 0x00, 0xa4, 0x20, 0x00, 0x00 };
-/* Default calibration for the nunchuck. It should be written to 0x20 - 0x3f of the
+static const u8 nunchuk_id[] = { 0x00, 0x00, 0xa4, 0x20, 0x00, 0x00 };
+/* Default calibration for the nunchuk. It should be written to 0x20 - 0x3f of the
extension register. 0x80 is the neutral x and y accelerators and 0xb3 is the
neutral z accelerometer that is adjusted for gravity. */
-static const u8 nunchuck_calibration[] =
+static const u8 nunchuk_calibration[] =
{
0x80, 0x80, 0x80, 0x00, // accelerometer x, y, z neutral
0xb3, 0xb3, 0xb3, 0x00, // x, y, z g-force values
@@ -52,9 +52,9 @@ Nunchuk::Nunchuk(WiimoteEmu::ExtensionReg& _reg) : Attachment(_trans("Nunchuk"),
// set up register
// calibration
- memcpy(&calibration, nunchuck_calibration, sizeof(nunchuck_calibration));
+ memcpy(&calibration, nunchuk_calibration, sizeof(nunchuk_calibration));
// id
- memcpy(&id, nunchuck_id, sizeof(nunchuck_id));
+ memcpy(&id, nunchuk_id, sizeof(nunchuk_id));
// this should get set to 0 on disconnect, but it isn't, o well
memset(m_shake_step, 0, sizeof(m_shake_step));